@@ -1883,8 +1883,11 @@ class Face3D(Base2DIn3D):
         try:
             move_vec = self._inward_pointing_vec(self)
         except ZeroDivisionError:  # face has duplicated start vertices; remove them
-            face = self.remove_colinear_vertices(tolerance)
-            move_vec = self._inward_pointing_vec(face)
+            try:
+                face = self.remove_colinear_vertices(tolerance)
+                move_vec = self._inward_pointing_vec(face)
+            except (AssertionError, ZeroDivisionError):  # zero area Face3D; use the center
+                return self.center
 
         move_vec = move_vec * (tolerance + 0.00001)
         point_on_face = self.boundary[0] + move_vec
@@ -1921,7 +1924,7 @@ class Face3D(Base2DIn3D):
                 cprods.append(cprodx)
                 ds.append(dx)
             # sum together the cross products of any vertices that are not colinear
-            min_d = (sum(ds) / len(ds)) * 1e-3  # rel tolerance for colinear vertices
+            min_d = (sum(ds) / len(ds)) * 0.05  # rel tolerance for colinear vertices
             normal = [0, 0, 0]
             for cprodx, dx in zip(cprods, ds):
                 if dx > min_d:
